@@ -622,7 +622,7 @@ int main(int argc, char *argv[])
         LOG(log_debug, logtype_cnid, "user: %s, volume %s, path %s",
             username ? username : "-", volname, volpath);
 
-        if (load_volumes(&obj, lv_all) != 0) {
+        if (load_volumes(&obj, LV_ALL) != 0) {
             LOG(log_severe, logtype_cnid, "main: error reloading config");
             goto loop_end;
         }
