@@ -158,6 +158,7 @@ int sys_get_eacontent(VFS_FUNC_ARGS_EA_GETCONTENT)
 {
     ssize_t   ret;
     uint32_t  attrsize;
+    size_t    extra = 0;
 
 #ifdef SOLARIS
     /* Protect special attributes set by NFS server */
@@ -171,6 +172,16 @@ int sys_get_eacontent(VFS_FUNC_ARGS_EA_GETCONTENT)
 
     /* Start building reply packet */
 
+    if (maxreply <= MAX_REPLY_EXTRA_BYTES) {
+        /*
+         * maxreply must be at least size of xattr + MAX_REPLY_EXTRA_BYTES (6)
+         * bytes. The 6 bytes are the AFP reply packets bitmap and length field.
+         */
+        memset(rbuf, 0, 4);
+        *rbuflen += 4;
+        return AFPERR_PARAM;
+    }
+
     maxreply -= MAX_REPLY_EXTRA_BYTES;
 
     if (maxreply > MAX_EA_SIZE)
@@ -178,19 +189,19 @@ int sys_get_eacontent(VFS_FUNC_ARGS_EA_GETCONTENT)
 
     LOG(log_debug7, logtype_afpd, "sys_getextattr_content(%s): attribute: \"%s\", size: %u", uname, attruname, maxreply);
     if (vol->v_flags & AFPVOL_EA_SAMBA) {
-        maxreply++;
+        extra = 1;
     }
 
     /* PBaranski fix */
     if (fd != -1) {
 	LOG(log_debug, logtype_afpd, "sys_get_eacontent(%s): file is already opened", uname);
-	ret = sys_fgetxattr(fd, attruname, rbuf +4, maxreply);
+	ret = sys_fgetxattr(fd, attruname, rbuf +4, maxreply + extra);
     } else {
 	if ((oflag & O_NOFOLLOW) ) {
-    	    ret = sys_lgetxattr(uname, attruname, rbuf +4, maxreply);
+    	    ret = sys_lgetxattr(uname, attruname, rbuf +4, maxreply + extra);
 	}
 	else {
-    	    ret = sys_getxattr(uname, attruname,  rbuf +4, maxreply);
+    	    ret = sys_getxattr(uname, attruname,  rbuf +4, maxreply + extra);
 	}
     }
     /* PBaranski fix */
@@ -209,6 +220,9 @@ int sys_get_eacontent(VFS_FUNC_ARGS_EA_GETCONTENT)
                 return AFPERR_NOITEM;
             return AFPERR_MISC;
 
+        case ERANGE:
+            return AFPERR_PARAM;
+
         default:
             LOG(log_debug, logtype_afpd, "sys_getextattr_content(%s): error: %s", attruname, strerror(errno));
             return AFPERR_MISC;
